@@ -104,9 +104,15 @@ class BlockContent extends ContentEntityBase implements BlockContentInterface {
    */
   public function postSave(EntityStorageInterface $storage, $update = TRUE) {
     parent::postSave($storage, $update);
+    static::invalidateBlockPluginCache();
+  }
 
-    // Invalidate the block cache to update custom block-based derivatives.
-    \Drupal::service('plugin.manager.block')->clearCachedDefinitions();
+  /**
+   * {@inheritdoc}
+   */
+  public static function postDelete(EntityStorageInterface $storage, array $entities) {
+    parent::postDelete($storage, $entities);
+    static::invalidateBlockPluginCache();
   }
 
   /**
@@ -237,4 +243,12 @@ class BlockContent extends ContentEntityBase implements BlockContentInterface {
     return $this;
   }
 
+  /**
+   * Invalidates the block plugin cache after changes and deletions.
+   */
+  protected static function invalidateBlockPluginCache() {
+    // Invalidate the block cache to update custom block-based derivatives.
+    \Drupal::service('plugin.manager.block')->clearCachedDefinitions();
+  }
+
 }
