@@ -96,9 +96,16 @@ class StylesCombo extends CKEditorPluginBase implements CKEditorPluginConfigurab
    * #element_validate handler for the "styles" element in settingsForm().
    */
   public function validateStylesValue(array $element, FormStateInterface $form_state) {
-    if ($this->generateStylesSetSetting($element['#value']) === FALSE) {
+    $styles_setting = $this->generateStylesSetSetting($element['#value']);
+    if ($styles_setting === FALSE) {
       $form_state->setError($element, t('The provided list of styles is syntactically incorrect.'));
     }
+    else {
+      $style_names = array_map(function ($style) { return $style['name']; }, $styles_setting);
+      if (count($style_names) !== count(array_unique($style_names))) {
+        $form_state->setError($element, t('Each style must have a unique label.'));
+      }
+    }
   }
 
   /**
