@@ -1,12 +1,8 @@
 <?php
 
-/**
- * @file
- * Contains \Drupal\file\Tests\FileManagedTestBase.
- */
-
 namespace Drupal\file\Tests;
 
+use Drupal\file\Entity\File;
 use Drupal\file\FileInterface;
 use Drupal\simpletest\WebTestBase;
 
@@ -152,10 +148,10 @@ abstract class FileManagedTestBase extends WebTestBase {
   function createFile($filepath = NULL, $contents = NULL, $scheme = NULL) {
     // Don't count hook invocations caused by creating the file.
     \Drupal::state()->set('file_test.count_hook_invocations', FALSE);
-    $file = entity_create('file', array(
+    $file = File::create([
       'uri' => $this->createUri($filepath, $contents, $scheme),
       'uid' => 1,
-    ));
+    ]);
     $file->save();
     // Write the record directly rather than using the API so we don't invoke
     // the hooks.
