@@ -1,13 +1,8 @@
 <?php
 
-/**
- * @file
- * Contains \Drupal\migrate\Event\MigratePreRowSaveEvent.
- */
-
 namespace Drupal\migrate\Event;
 
-use Drupal\migrate\Entity\MigrationInterface;
+use Drupal\migrate\Plugin\MigrationInterface;
 use Drupal\migrate\Row;
 use Symfony\Component\EventDispatcher\Event;
 
@@ -26,14 +21,14 @@ class MigratePreRowSaveEvent extends Event {
   /**
    * Migration entity.
    *
-   * @var \Drupal\migrate\Entity\MigrationInterface
+   * @var \Drupal\migrate\Plugin\MigrationInterface
    */
   protected $migration;
 
   /**
    * Constructs a pre-save event object.
    *
-   * @param \Drupal\migrate\Entity\MigrationInterface $migration
+   * @param \Drupal\migrate\Plugin\MigrationInterface $migration
    *   Migration entity.
    */
   public function __construct(MigrationInterface $migration, Row $row) {
@@ -44,7 +39,7 @@ class MigratePreRowSaveEvent extends Event {
   /**
    * Gets the migration entity.
    *
-   * @return \Drupal\migrate\Entity\MigrationInterface
+   * @return \Drupal\migrate\Plugin\MigrationInterface
    *   The migration entity being imported.
    */
   public function getMigration() {
