@@ -296,6 +296,24 @@ class PagePreviewTest extends NodeTestBase {
 
     // Check that the revision log field has the correct value.
     $this->assertFieldByName('revision_log[0][value]', $edit['revision_log[0][value]'], 'Revision log field displayed.');
+
+    // Save the node after coming back from the preview page so we can create a
+    // forward revision for it.
+    $this->drupalPostForm(NULL, [], t('Save'));
+    $node = $this->drupalGetNodeByTitle($edit[$title_key]);
+
+    // Check that previewing a forward revision of a node works. This can not be
+    // accomplished through the UI so we have to use API calls.
+    // @todo Change this test to use the UI when we will be able to create
+    // forward revisions in core.
+    // @see https://www.drupal.org/node/2725533
+    $node->setNewRevision(TRUE);
+    $node->isDefaultRevision(FALSE);
+
+    /** @var \Drupal\Core\Controller\ControllerResolverInterface $controller_resolver */
+    $controller_resolver = \Drupal::service('controller_resolver');
+    $node_preview_controller = $controller_resolver->getControllerFromDefinition('\Drupal\node\Controller\NodePreviewController::view');
+    $node_preview_controller($node, 'default');
   }
 
   /**
