@@ -6,6 +6,7 @@
  * upgrade path of https://www.drupal.org/node/2455125.
  */
 
+use Drupal\Component\Serialization\Yaml;
 use Drupal\Core\Database\Database;
 
 $connection = Database::getConnection();
@@ -13,7 +14,7 @@ $connection = Database::getConnection();
 // Structure of a view with timestamp fields.
 $views_configs = [];
 
-$views_configs[] = \Drupal\Component\Serialization\Yaml::decode(file_get_contents(__DIR__ . '/drupal-8.views-entity-views-data-2455125.yml'));
+$views_configs[] = Yaml::decode(file_get_contents(__DIR__ . '/drupal-8.views-entity-views-data-2455125.yml'));
 
 foreach ($views_configs as $views_config) {
 $connection->insert('config')
