@@ -22,7 +22,7 @@ use Symfony\Component\DependencyInjection\ContainerInterface;
 class TaxonomyIndexTid extends ManyToOne {
 
   // Stores the exposed input for this filter.
-  var $validated_exposed_input = NULL;
+  public $validated_exposed_input = NULL;
 
   /**
    * The vocabulary storage.
@@ -322,7 +322,7 @@ class TaxonomyIndexTid extends ManyToOne {
 
     // We only validate if they've chosen the text field style.
     if ($this->options['type'] != 'textfield') {
-      if ($form_state->getValue($identifier) != 'All')  {
+      if ($form_state->getValue($identifier) != 'All') {
         $this->validated_exposed_input = (array) $form_state->getValue($identifier);
       }
       return;
