@@ -28,7 +28,7 @@ class Name extends InOperator {
       '#target_type' => 'user',
       '#tags' => TRUE,
       '#default_value' => $default_value,
-      '#process_default_value' => FALSE,
+      '#process_default_value' => $this->isExposed(),
     );
 
     $user_input = $form_state->getUserInput();
