@@ -2,6 +2,7 @@
 
 namespace Drupal\Tests\Core\DrupalKernel;
 
+use Composer\Autoload\ClassLoader;
 use Drupal\Core\DrupalKernel;
 use Drupal\Core\Site\Settings;
 use Drupal\Tests\UnitTestCase;
@@ -24,7 +25,7 @@ class DiscoverServiceProvidersTest extends UnitTestCase {
       ),
     ));
 
-    $kernel = new DrupalKernel('prod', new \Composer\Autoload\ClassLoader());
+    $kernel = new DrupalKernel('prod', new ClassLoader());
     $kernel->discoverServiceProviders();
 
     $expect = array(
@@ -44,7 +45,7 @@ class DiscoverServiceProvidersTest extends UnitTestCase {
    */
   public function testDiscoverServiceNoContainerYamls() {
     new Settings([]);
-    $kernel = new DrupalKernel('prod', new \Composer\Autoload\ClassLoader());
+    $kernel = new DrupalKernel('prod', new ClassLoader());
     $kernel->discoverServiceProviders();
 
     $expect = [
